@@ -1,4 +1,4 @@
-# Copyright 2001-2019, Paul Johnson (paul@pjcj.net)
+# Copyright 2001-2022, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -12,7 +12,7 @@ use warnings;
 
 our $VERSION;
 BEGIN {
-our $VERSION = '1.36'; # VERSION
+our $VERSION = '1.37'; # VERSION
 }
 
 use Devel::Cover::DB;
@@ -153,9 +153,17 @@ sub _highlight_perltidy {
     @coloured
 }
 
-*_highlight = $Have_PPI      ? \&_highlight_ppi
-            : $Have_perltidy ? \&_highlight_perltidy
-            :                  sub {};
+sub _highlight {
+    if ($Have_PPI && !$R{options}{option}{noppihtml}) {
+        return _highlight_ppi(@_);
+    } else {
+        if ($Have_perltidy && !$R{options}{option}{noperltidy}) {
+            return _highlight_perltidy(@_);
+        }
+    }
+
+    return;
+}
 
 sub print_file {
     my @lines;
@@ -164,7 +172,9 @@ sub print_file {
     open F, $R{file} or warn("Unable to open $R{file}: $!\n"), return;
     my @all_lines = <F>;
 
-    @all_lines = _highlight(@all_lines) if $Have_highlighter;
+    if (!($R{options}{option}{noppihtml} && $R{options}{option}{noperltidy})) {
+        @all_lines = _highlight(@all_lines) if $Have_highlighter;
+    }
 
     my $linen = 1;
     LINE: while (defined(my $l = shift @all_lines)) {
@@ -375,6 +385,8 @@ sub get_options {
     die "Invalid command line options" unless
         GetOptions($opt->{option},
                    qw(
+                       noppihtml
+                       noperltidy
                        outputfile=s
                        restrict!
                      ));
@@ -453,7 +465,7 @@ package Devel::Cover::Report::Html_basic::Template::Provider;
 use strict;
 use warnings;
 
-our $VERSION = '1.36'; # VERSION
+our $VERSION = '1.37'; # VERSION
 
 use base "Template::Provider";
 
@@ -473,7 +485,7 @@ $Templates{html} = <<'EOT';
 <html xmlns="http://www.w3.org/1999/xhtml">
 <!--
 This file was generated by Devel::Cover Version [% R.version %]
-Devel::Cover is copyright 2001-2019, Paul Johnson (paul@pjcj.net)
+Devel::Cover is copyright 2001-2022, Paul Johnson (paul@pjcj.net)
 Devel::Cover is free. It is licensed under the same terms as Perl itself.
 The latest version of Devel::Cover should be available from my homepage:
 http://www.pjcj.net
@@ -812,7 +824,7 @@ Devel::Cover::Report::Html_basic - HTML backend for Devel::Cover
 
 =head1 VERSION
 
-version 1.36
+version 1.37
 
 =head1 SYNOPSIS
 
@@ -828,8 +840,10 @@ highlighting if C<PPI::HTML> or C<Perl::Tidy> is installed.
 
 The following command line options are supported:
 
- -outputfile           - name of output file             (default coverage.html)
- -restrict             - add restrict to regex form      (default on)
+ -outputfile  - name of output file              (default coverage.html)
+ -restrict    - add restrict to regex form       (default on)
+ -noppihtml   - disables PPI::HTML highlighting  (default off)
+ -noperltidy  - disables Perl::Tidy highlighting (default off)
 
 =head1 SEE ALSO
 
@@ -841,7 +855,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2001-2019, Paul Johnson (paul@pjcj.net)
+Copyright 2001-2022, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
